@@ -2,11 +2,6 @@ package Pcore::Util::GeoIP;
 
 use Pcore -const;
 
-const our $GEOIP_STANDARD     => 0;    # PP
-const our $GEOIP_MEMORY_CACHE => 1;    # PP
-const our $GEOIP_CHECK_CACHE  => 2;    # when using memory cache you can force a reload if the file is updated by setting GEOIP_CHECK_CACHE
-const our $GEOIP_INDEX_CACHE  => 4;    # caches the most frequently accessed index portion of the database, resulting in faster lookups than GEOIP_STANDARD, but less memory usage than GEOIP_MEMORY_CACHE - useful for larger databases such as GeoIP Legacy Organization and GeoIP City. Note, for GeoIP Country, Region and Netspeed databases, GEOIP_INDEX_CACHE is equivalent to GEOIP_MEMORY_CACHE
-
 const our $TYPE_COUNTRY    => 1;
 const our $TYPE_COUNTRY_V6 => 2;
 const our $TYPE_COUNTRY2   => 3;
@@ -23,10 +18,6 @@ const our $RES => {
     $TYPE_CITY2      => [ '/data/geoip2_city.dat',      'http://geolite.maxmind.com/download/geoip/database/GeoLite2-City.mmdb.gz' ],
 };
 
-our $GEOIP_PURE_PERL          = 0;                     # force to use pure perl mode
-our $GEOIP_COUNTRY_CACHE_MODE = $GEOIP_MEMORY_CACHE;
-our $GEOIP_CITY_CACHE_MODE    = $GEOIP_INDEX_CACHE;
-
 my $H;
 
 sub clear {
@@ -123,47 +114,9 @@ sub _get_h ($type) {
         );
     }
     else {
-        my $default_cache_mode;
+        state $init = !!require Geo::IP;
 
-        my $use_pure_perl = $GEOIP_PURE_PERL;
-
-        if ($use_pure_perl) {
-            state $init = !!require Geo::IP::PurePerl;
-        }
-        else {
-            $use_pure_perl = try {
-                state $init = !!require Geo::IP;
-
-                return 0;
-            }
-            catch {
-                state $init = !!require Geo::IP::PurePerl;
-
-                return 1;
-            };
-        }
-
-        if ( $type == $TYPE_COUNTRY ) {
-            $default_cache_mode = $GEOIP_COUNTRY_CACHE_MODE;
-        }
-        elsif ( $type == $TYPE_COUNTRY_V6 ) {
-            $default_cache_mode = $GEOIP_COUNTRY_CACHE_MODE;
-        }
-        elsif ( $type == $TYPE_CITY ) {
-            $default_cache_mode = $GEOIP_CITY_CACHE_MODE;
-        }
-        elsif ( $type == $TYPE_CITY_V6 ) {
-            $default_cache_mode = $GEOIP_CITY_CACHE_MODE;
-        }
-
-        # use $GEOIP_MEMORY_CACHE instead of $GEOIP_INDEX_CACHE if $GEOIP_INDEX_CACHE is not supported
-        my $flags = $use_pure_perl && $default_cache_mode == $GEOIP_INDEX_CACHE ? $GEOIP_MEMORY_CACHE : $default_cache_mode;
-
-        $flags = $flags | $GEOIP_CHECK_CACHE if !$use_pure_perl;
-
-        my $class = $use_pure_perl ? 'Geo::IP::PurePerl' : 'Geo::IP';
-
-        $H->{$type} = $class->open( $path, $flags );
+        $H->{$type} = Geo::IP->open( $path, Geo::IP::GEOIP_MEMORY_CACHE() | Geo::IP::GEOIP_CHECK_CACHE() );
     }
 
     return;
@@ -176,7 +129,7 @@ sub _get_h ($type) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 41                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 32                   │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
